powered by
Prints the call, agglomerative coefficient, ordering of objects and distances between merging clusters ('Height') of an agnes object.
agnes
This is a method for the generic print() function for objects inheriting from class agnes, see agnes.object.
print()
agnes.object
# S3 method for agnes print(x, ...)
summary.agnes producing more output; agnes, agnes.object, print, print.default.
summary.agnes
print
print.default